==> terminal_stopwatch-0.1.1.tar.gz: terminal_stopwatch-0.1.1/README.md <==
# Terminal Stopwatch

A terminal-based stopwatch application featuring ASCII art display.

## Features

- ⏱️ Time Measurement
- 🎯 Lap Time Recording
- 🎨 ASCII Art Time Display
- 🌈 Colorful Terminal Interface

## Installation

### Using Executable (Recommended)

1. Download the `stopwatch` executable from the latest release
2. Grant execution permission in terminal:
   ```bash
   chmod +x ./stopwatch
   ```
3. Run:
   ```bash
   ./stopwatch
   ```

### From Source Code

1. Clone the repository:
   ```bash
   git clone https://github.com/yourusername/stopwatch.git
   cd stopwatch
   ```

2. Install Poetry (Package Manager):
   ```bash
   curl -sSL https://install.python-poetry.org | python3 -
   ```

3. Install dependencies:
   ```bash
   poetry install
   ```

4. Run:
   ```bash
   poetry run python main.py
   ```

## Usage

Use the following keys to control the stopwatch:

- `s`: 🚀 Start/Pause
- `l`: 📝 Record Lap Time
- `r`: 🔄 Reset
- `q`: 🚫 Quit

## Development Environment

- Python 3.11+
- Poetry (Dependency Management)
- PyInstaller (Executable Creation)

## Dependencies

- pyfiglet: ASCII Art Generation
- colorama: Terminal Color Support
- readchar: Keyboard Input Handling

## License

MIT License

## Contributing

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## Author

- taejun (dugudugu0622@gmail.com)

==> terminal_stopwatch-1.1.0.tar.gz: terminal_stopwatch-1.1.0/README.md <==
# Terminal Stopwatch

A terminal-based stopwatch application featuring ASCII art display.

## Features

- ⏱️ Time Measurement
- 🎯 Lap Time Recording
- 🎨 ASCII Art Time Display
- 🌈 Colorful Terminal Interface

## Installation

### Using pip (Recommended)

```bash
pip install terminal-stopwatch
```

Then run:
```bash
stopwatch
```

### Using Executable

1. Download the `stopwatch` executable from the latest release
2. Grant execution permission in terminal:
   ```bash
   chmod +x ./stopwatch
   ```
3. Run:
   ```bash
   ./stopwatch
   ```

### From Source Code

1. Clone the repository:
   ```bash
   git clone https://github.com/yourusername/stopwatch.git
   cd stopwatch
   ```

2. Install Poetry (Package Manager):
   ```bash
   curl -sSL https://install.python-poetry.org | python3 -
   ```

3. Install dependencies:
   ```bash
   poetry install
   ```

4. Run:
   ```bash
   poetry run python main.py
   ```

## Usage

Use the following keys to control the stopwatch:

- `s`: 🚀 Start/Pause
- `l`: 📝 Record Lap Time
- `r`: 🔄 Reset
- `q`: 🚫 Quit

## Development Environment

- Python 3.11+
- Poetry (Dependency Management)
- PyInstaller (Executable Creation)

## Dependencies

- pyfiglet: ASCII Art Generation
- colorama: Terminal Color Support
- readchar: Keyboard Input Handling

## License

MIT License

## Contributing

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## Author

- taejun (dugudugu0622@gmail.com)
